<?php

declare(strict_types=1);

namespace Drupal\views_tag_view_display\Plugin\views\display_extender;

use Drupal\views\Plugin\views\display_extender\DisplayExtenderPluginBase;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\StringTranslation\StringTranslationTrait;

/**
 * Views tag view display extender plugin.
 *
 * @ingroup views_display_extender_plugins
 *
 * @ViewsDisplayExtender(
 *   id = "views_tag_view_display",
 *   title = @Translation("Display view tags"),
 *   help = @Translation("Add tags to a display view."),
 *   no_ui = FALSE
 * )
 */
final class ViewsTagViewDisplayExtender extends DisplayExtenderPluginBase {

  use StringTranslationTrait;

  /**
   * Provide the key options for this plugin.
   */
  public function defineOptionsAlter(&$options) :void {
    $options[$this->pluginId] = [
      'contains' => [
        'value' => ['default' => ''],
      ],
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function optionsSummary(&$categories, &$options) :void {
    $option = $this->getOption($this->pluginId);
    $value = isset($option) ? mb_substr(strip_tags($option), 0, 60) . '…' : $this->t('None');

    $options[$this->pluginId] = [
      'category' => 'other',
      'title' => $this->t('Display view Tags'),
      'value' => $value,
    ];
  }


  /**
   * Provide a form to edit options for this plugin.
   */
  public function buildOptionsForm(&$form, FormStateInterface $form_state) :void {
    if ($form_state->get('section') === $this->pluginId) {
      $form['#title'] = $this->t('Views display tags');

      $default_value = $this->getOption($this->pluginId);
      $form[$this->pluginId] = [
        '#type' => 'textarea',
        '#title' => $this->t('Tags for this display'),
        '#description' => $this->t('Write tags separated by comma.'),
        '#default_value' => $default_value,
      ];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitOptionsForm(&$form, FormStateInterface $form_state) :void {
    if ($form_state->get('section') == $this->pluginId) {
      $value = $form_state->getValue($this->pluginId);
      $this->setOption($this->pluginId, $value);
    }
  }

  /**
   * Validate the options form.
   */
  public function validateOptionsForm(&$form, FormStateInterface $form_state) { }

  /**
   * Set up any variables on the view prior to execution.
   */
  public function preExecute() { }

  /**
   * Inject anything into the query that the display_extender handler needs.
   */
  public function query() { }

  /**
   * {@inheritdoc}
   */
  public function getOption($option) {
    if (\array_key_exists($option, $this->options)) {
      return $this->options[$option];
    }
  }

  /**
   * {@inheritdoc}
   */
  public function setOption($option, $value) {
    $this->display['display_options'][$option] = $value;
    return $this->options[$option] = $value;
  }

  /**
   * Return the value storage in views_tag_view_display.
   *
   * @return mixed
   *   return the value storaged.
   */
  public function getValue() :mixed {
    return $this->options[$this->pluginId];
  }

}
